==> uwikicms-1.1.4.tar.gz: uwikicms-1.1.4/php/_uwikicms/include/langfr.php <==
<?php
/*
 UWiKiCMS is a lightweight web content management system.
 Copyright (C) 2005, 2006, 2007, 2009, 2013 Christian Mauduit <ufoot@ufoot.org>

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License as
 published by the Free Software Foundation; either version 2 of
 the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public
 License along with this program; if not, write to the Free
 Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA  02110-1301  USA
*/

$this->messages=array
  (
   "about"=>"<a href=\"http://www.ufoot.org/uwikicms\">UWiKiCMS</a> version %s par <a href=\"mailto:ufoot@ufoot.org\">U-Foot</a>",

   "title"=>"Titre",
   "text"=>"Texte",
   "path"=>"Chemin",
   "order"=>"Ordre",
   "submit"=>"Valider",
   "create"=>"Cr&eacute;er",
   "update"=>"Modifier",
   "delete"=>"Supprimer",
   "clear_cache"=>"Vider le cache",
   "renum"=>"Renum&eacute;rotation",
   "all_in_one"=>"Tout sur une page",
   "no_title"=>"Sans titre",
   "doc_created"=>"Document cr&eacute;&eacute;",
   "doc_updated"=>"Document mis &agrave; jour",
   "doc_deleted"=>"Document supprim&eacute;",
   "cache_cleared"=>"Cache vid&eacute;",
   "renum_done"=>"Renum&eacute;rotation termin&eacute;e",
   "confirm_delete"=>"&Ecirc;tes vous s&ucirc;r de vouloir supprimer ce document?",
   "image_created"=>"Image cr&eacute;&eacute;e",
   "image_updated"=>"Image mise &agrave; jour",
   "image_deleted"=>"Image supprim&eacute;e",
   "confirm_delete_image"=>"&Ecirc;tes vous s&ucirc;r de vouloir supprimer cette image?",   
   "confirm_clear_cache"=>"&Ecirc;tes vous s&ucirc;r de vouloir vider le cache?",
   "confirm_renum"=>"&Ecirc;tes vous s&ucirc;r de vouloir renum&eacute;roter?",
   "confirm_all_in_one"=>"&Ecirc;tes vous s&ucirc;r de vouloir tout afficher sur une seule page? Cela peut prendre beaucoup de temps...",
   "title_403"=>"403 Interdit",
   "title_404"=>"404 Non trouv&eacute;",
   "title_loginform"=>"Connexion",
   "title_login"=>"Connexion",
   "title_logout"=>"D&eacute;connexion",
   "title_createform"=>"Nouveau document",
   "title_imagecreateform"=>"Nouvelle image",
   "title_clearcacheform"=>"Vider le cache",
   "title_clearcache"=>"Vider le cache",
   "title_renumform"=>"Renum&eacute;roter",
   "title_renum"=>"Renum&eacute;roter",
   "title_allinoneform"=>"Tout sur une page",
   "title_about"=>"&Agrave; propos d'UWiKiCMS",
   "status"=>"&Eacute;tat",
   "status_0"=>"Public",
   "status_1"=>"Prot&eacute;g&eacute; par un mot de passe",
   "status_2"=>"Priv&eacute;",
   "status_3"=>"Confidentiel",
   "rights_0"=>"Copyright &copy; %s %s. Document plac&eacute; sous licence <a href=\"http://www.gnu.org/copyleft/fdl.html\">GNU FDL</a>.",
   "rights_1"=>"L'acc&egrave;s &agrave; cette page est prot&eacute;g&eacute; par un mot de passe.",
   "rights_2"=>"Document priv&eacute;.",
   "rights_3"=>"Document confidentiel.",
   "meta_description"=>"%s (pas de description d&eacute;taill&eacute;e)",
   "meta_copyright"=>"Copyleft &copy; %s %s",
   "page_generated_by_uwikicms"=>"Page g&eacute;n&eacute;r&eacute;e par <a href=\"http://www.ufoot.org/uwikicms\">UWiKiCMS</a> %s le %s.",
   "xul_generated_by_uwikicms"=>"Interface XUL g&eacute;n&eacute;r&eacute;e par UWiKiCMS %s le %s.",
   "last_update"=>"Mis &agrave; jour le %s.",
   "source"=>"Source&nbsp;:",
   "action_root"=>"Accueil",
   "action_login"=>"Se connecter",
   "action_logout"=>"Se d&eacute;connecter (%s)",
   "action_view"=>"Voir la page",
   "action_rss"=>"Flux RSS",
   "action_tree"=>"Plan du site",
   "action_css_yes"=>"Avec CSS",
   "action_css_no"=>"Sans CSS",
   "action_update"=>"Modifier",
   "action_delete"=>"Supprimer",
   "action_new"=>"Nouvelle page",
   "action_imagenew"=>"Nouvelle image",
   "action_clearcache"=>"Vider le cache",
   "action_renum"=>"Renum&eacute;roter",
   "action_help"=>"Aide",
   "action_allinone"=>"Tout sur une page",
   "action_gallery"=>"Diaporama (Mozilla/Firefox)",
   "login_user"=>"Identifiant",
   "login_password"=>"Mot de passe",
   "login_connect"=>"Se connecter",
   "logout_success"=>"Vous &ecirc;tes d&eacute;connect&eacute;.",
   "403_forbidden"=>"Erreur HTTP 403: vous n'avez pas le droit de visualiser cette page.",
   "404_not_found"=>"Erreur HTTP 404: le document demand&eacute; n'a pas &eacute;t&eacute; trouv&eacute;.",
   "continue"=>"Continuer.",
   "view_lang_en"=>"English",
   "view_lang_fr"=>"Fran&ccedil;ais",
   "view_lang_de"=>"Deutsch",
   "view_lang_es"=>"Espaol",
   "view_lang_da"=>"Danois",
   "translate"=>"Traduire&nbsp;:",
   "home"=>"Accueil&nbsp;: %s",
   "up"=>"Parent&nbsp;: %s",
   "next"=>"Suivant&nbsp;: %s",
   "prev"=>"Pr&eacute;c&eacute;dent&nbsp;: %s",
   "this_is_a_tree"=>"Plan du site \"%s\"",
   "this_is_a_subtree"=>"Plan de la section \"%s\"",
   "all_in_one_site"=>"Tout le contenu du site \"%s\" le %s",
   "all_in_one_subsite"=>"Tout le contenu de la section \"%s\" le %s",
   "display_status_0"=>"Seuls les contenus publics sont affich&eacute;s.",
   "display_status_1"=>"Les contenus publics et prot&eacute;g&eacute;s par mot de passe sont affich&eacute;s.",
   "display_status_2"=>"Les contenus publics, prot&eacute;g&eacute;s par mot de passe et priv&eacute;s sont affich&eacute;s.",
   "display_status_3"=>"Tous les contenus (publics, prot&eacute;g&eacute;s, priv&eacute;s, confidentiels) sont affich&eacute;s.",
   "alt"=>"Titre",
   "longdesc"=>"Description",
   "imagefile"=>"Fichier image",
   "filename_width_height_size"=>"%s - %d&nbsp;x&nbsp;%d - %so",
   "current_image"=>"Image actuelle",
   "allinone_status"=>"N'afficher que les documents dans cet &eacute;tat",
   "allinone_intro"=>"Texte d'introduction",
   "allinone_max_size"=>"Taille max des images (en pixels)",
   "gallery_title"=>"Diaporama XUL",
   "gallery_prev"=>"Image prcdente",
   "gallery_next"=>"Image suivante",
   "gallery_empty"=>"Aucune image dans ce diaporama",
   "google_search"=>"Recherche Google",
   "rss_about"=>"Flux RSS concernant %s",
   "do_date_update"=>"Mettre &agrave; jour la date de modification",

   ""=>""
   );

?>

==> uwikicms-1.1.5.tar.gz: uwikicms-1.1.5/php/_uwikicms/include/langfr.php <==
<?php
/*
 UWiKiCMS is a lightweight web content management system.
 Copyright (C) 2005, 2006, 2007, 2009, 2013, 2015 Christian Mauduit <ufoot@ufoot.org>

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License as
 published by the Free Software Foundation; either version 2 of
 the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public
 License along with this program; if not, write to the Free
 Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA  02110-1301  USA
*/

$this->messages=array
  (
   "about"=>"<a href=\"http://www.ufoot.org/uwikicms\">UWiKiCMS</a> version %s par <a href=\"mailto:ufoot@ufoot.org\">U-Foot</a>",

   "title"=>"Titre",
   "text"=>"Texte",
   "path"=>"Chemin",
   "order"=>"Ordre",
   "submit"=>"Valider",
   "create"=>"Cr&eacute;er",
   "update"=>"Modifier",
   "delete"=>"Supprimer",
   "clear_cache"=>"Vider le cache",
   "renum"=>"Renum&eacute;rotation",
   "all_in_one"=>"Tout sur une page",
   "no_title"=>"Sans titre",
   "doc_created"=>"Document cr&eacute;&eacute;",
   "doc_updated"=>"Document mis &agrave; jour",
   "doc_deleted"=>"Document supprim&eacute;",
   "cache_cleared"=>"Cache vid&eacute;",
   "renum_done"=>"Renum&eacute;rotation termin&eacute;e",
   "confirm_delete"=>"&Ecirc;tes vous s&ucirc;r de vouloir supprimer ce document?",
   "image_created"=>"Image cr&eacute;&eacute;e",
   "image_updated"=>"Image mise &agrave; jour",
   "image_deleted"=>"Image supprim&eacute;e",
   "confirm_delete_image"=>"&Ecirc;tes vous s&ucirc;r de vouloir supprimer cette image?",   
   "confirm_clear_cache"=>"&Ecirc;tes vous s&ucirc;r de vouloir vider le cache?",
   "confirm_renum"=>"&Ecirc;tes vous s&ucirc;r de vouloir renum&eacute;roter?",
   "confirm_all_in_one"=>"&Ecirc;tes vous s&ucirc;r de vouloir tout afficher sur une seule page? Cela peut prendre beaucoup de temps...",
   "title_403"=>"403 Interdit",
   "title_404"=>"404 Non trouv&eacute;",
   "title_loginform"=>"Connexion",
   "title_login"=>"Connexion",
   "title_logout"=>"D&eacute;connexion",
   "title_createform"=>"Nouveau document",
   "title_imagecreateform"=>"Nouvelle image",
   "title_clearcacheform"=>"Vider le cache",
   "title_clearcache"=>"Vider le cache",
   "title_renumform"=>"Renum&eacute;roter",
   "title_renum"=>"Renum&eacute;roter",
   "title_allinoneform"=>"Tout sur une page",
   "title_about"=>"&Agrave; propos d'UWiKiCMS",
   "status"=>"&Eacute;tat",
   "status_0"=>"Public",
   "status_1"=>"Prot&eacute;g&eacute; par un mot de passe",
   "status_2"=>"Priv&eacute;",
   "status_3"=>"Confidentiel",
   "rights_0"=>"Copyright &copy; %s %s. Document plac&eacute; sous licence <a href=\"http://www.gnu.org/copyleft/fdl.html\">GNU FDL</a>.",
   "rights_1"=>"L'acc&egrave;s &agrave; cette page est prot&eacute;g&eacute; par un mot de passe.",
   "rights_2"=>"Document priv&eacute;.",
   "rights_3"=>"Document confidentiel.",
   "meta_description"=>"%s (pas de description d&eacute;taill&eacute;e)",
   "meta_copyright"=>"Copyleft &copy; %s %s",
   "page_generated_by_uwikicms"=>"Page g&eacute;n&eacute;r&eacute;e par <a href=\"http://www.ufoot.org/uwikicms\">UWiKiCMS</a> %s le %s.",
   "xul_generated_by_uwikicms"=>"Interface XUL g&eacute;n&eacute;r&eacute;e par UWiKiCMS %s le %s.",
   "last_update"=>"Mis &agrave; jour le %s.",
   "source"=>"Source&nbsp;:",
   "action_root"=>"Accueil",
   "action_login"=>"Se connecter",
   "action_logout"=>"Se d&eacute;connecter (%s)",
   "action_view"=>"Voir la page",
   "action_rss"=>"Flux RSS",
   "action_tree"=>"Plan du site",
   "action_css_yes"=>"Avec CSS",
   "action_css_no"=>"Sans CSS",
   "action_update"=>"Modifier",
   "action_delete"=>"Supprimer",
   "action_new"=>"Nouvelle page",
   "action_imagenew"=>"Nouvelle image",
   "action_clearcache"=>"Vider le cache",
   "action_renum"=>"Renum&eacute;roter",
   "action_help"=>"Aide",
   "action_allinone"=>"Tout sur une page",
   "action_gallery"=>"Diaporama (Mozilla/Firefox)",
   "login_user"=>"Identifiant",
   "login_password"=>"Mot de passe",
   "login_connect"=>"Se connecter",
   "logout_success"=>"Vous &ecirc;tes d&eacute;connect&eacute;.",
   "403_forbidden"=>"Erreur HTTP 403: vous n'avez pas le droit de visualiser cette page.",
   "404_not_found"=>"Erreur HTTP 404: le document demand&eacute; n'a pas &eacute;t&eacute; trouv&eacute;.",
   "continue"=>"Continuer.",
   "view_lang_en"=>"English",
   "view_lang_fr"=>"Fran&ccedil;ais",
   "view_lang_de"=>"Deutsch",
   "view_lang_es"=>"Espaol",
   "view_lang_da"=>"Danois",
   "translate"=>"Traduire&nbsp;:",
   "home"=>"Accueil&nbsp;: %s",
   "up"=>"Parent&nbsp;: %s",
   "next"=>"Suivant&nbsp;: %s",
   "prev"=>"Pr&eacute;c&eacute;dent&nbsp;: %s",
   "this_is_a_tree"=>"Plan du site \"%s\"",
   "this_is_a_subtree"=>"Plan de la section \"%s\"",
   "all_in_one_site"=>"Tout le contenu du site \"%s\" le %s",
   "all_in_one_subsite"=>"Tout le contenu de la section \"%s\" le %s",
   "display_status_0"=>"Seuls les contenus publics sont affich&eacute;s.",
   "display_status_1"=>"Les contenus publics et prot&eacute;g&eacute;s par mot de passe sont affich&eacute;s.",
   "display_status_2"=>"Les contenus publics, prot&eacute;g&eacute;s par mot de passe et priv&eacute;s sont affich&eacute;s.",
   "display_status_3"=>"Tous les contenus (publics, prot&eacute;g&eacute;s, priv&eacute;s, confidentiels) sont affich&eacute;s.",
   "alt"=>"Titre",
   "longdesc"=>"Description",
   "imagefile"=>"Fichier image",
   "filename_width_height_size"=>"%s - %d&nbsp;x&nbsp;%d - %so",
   "current_image"=>"Image actuelle",
   "allinone_status"=>"N'afficher que les documents dans cet &eacute;tat",
   "allinone_intro"=>"Texte d'introduction",
   "allinone_max_size"=>"Taille max des images (en pixels)",
   "gallery_title"=>"Diaporama XUL",
   "gallery_prev"=>"Image prcdente",
   "gallery_next"=>"Image suivante",
   "gallery_empty"=>"Aucune image dans ce diaporama",
   "google_search"=>"Recherche Google",
   "rss"=>"Flux RSS concernant %s",
   "rss_about"=>"Flux RSS concernant %s",
   "facebook"=>"Partager %s sur facebook",
   "facebook_about"=>"Partager %s sur facebook",
   "twitter"=>"Tweet %s",
   "twitter_about"=>"Faire un tweet &agrave; propos de %s",
   "do_date_update"=>"Mettre &agrave; jour la date de modification",

   ""=>""
   );

?>
